@@ -18,13 +18,16 @@ if getattr(sys, "frozen", False):
 else:
     APP_DIR = os.path.join(os.path.dirname(os.path.abspath(sys.argv[0])), "..")
 
+VERSION_SUFFIX = ''
+
 APP_NAME = "PhotoFilmStrip"
-APP_VERSION = "3.7.3"
-APP_VERSION_EX = "%s-%s" % (APP_VERSION, SCM_REV)
+APP_VERSION = "4.0.0"
+APP_VERSION_SUFFIX = "%s%s" % (APP_VERSION, VERSION_SUFFIX)
+APP_VERSION_FULL = "%s-%s" % (APP_VERSION_SUFFIX, SCM_REV)
 APP_SLOGAN = "PhotoFilmStrip - Creates movies out of your pictures."
 APP_DESCRIPTION = """\
 PhotoFilmStrip creates movies out of your pictures in just 3 steps. First select your photos, customize the motion path and render the video. There are several output possibilities for VCD, SVCD, DVD up to FULL-HD.
 """
 APP_URL = "http://www.photofilmstrip.org"
-DEVELOPERS = [u"Jens Göpfert"]
+DEVELOPERS = ["Jens Göpfert"]
 TRANSLATORS = ["Teza Lprod - http://lprod.org", "geogeo - http://www.geogeo.gr"]
