@@ -1,30 +1,16 @@
-# encoding: UTF-8
+# -*- coding: utf-8 -*-
 #
 # PhotoFilmStrip - Creates movies out of your pictures.
 #
 # Copyright (C) 2014 Jens Goepfert
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
 
 import logging
-import threading
 import time
 
 from gi.repository import Gst
-from gi.repository import GObject
+
+from photofilmstrip.core.GMainLoop import GMainLoop
 
 
 class GPlayer:
@@ -33,7 +19,8 @@ class GPlayer:
         self.__filename = filename
         self.__pipeline = None
         self.__length = None
-        self.__gtkMainloop = None
+        self.__position = None
+        self.__log = logging.getLogger("GPlayer").log
 
         self.__Identify()
 
@@ -58,17 +45,29 @@ class GPlayer:
 
         pipeline.set_state(Gst.State.PLAYING)
 
+        bus = pipeline.get_bus()
         hasResult = False
+        duration = None
         while not hasResult:
-            msg = pipeline.get_bus().pop()
+            msg = bus.pop()
             if msg is None:
                 time.sleep(0.001)
                 continue
+
+            if msg.type == Gst.MessageType.ERROR:
+                duration = None
+                err, debug = msg.parse_error()
+                self.__log(logging.ERROR, "Error received from element %s: %s",
+                              msg.src.get_name(), err)
+                self.__log(logging.DEBUG, "Debugging information: %s", debug)
+                break
+
             hasResult, duration = pipeline.query_duration(Gst.Format.TIME)
 
         pipeline.set_state(Gst.State.NULL)
 
-        self.__length = duration // Gst.MSECOND
+        if duration is not None:
+            self.__length = duration // Gst.MSECOND
 
     def GetFilename(self):
         return self.__filename
@@ -88,15 +87,18 @@ class GPlayer:
 
             audioDec = Gst.ElementFactory.make("decodebin")
             audioConv = Gst.ElementFactory.make("audioconvert")
+            audioResample = Gst.ElementFactory.make("audioresample")
             audioSink = Gst.ElementFactory.make("autoaudiosink")
 
             pipeline.add(fileSrc)
             pipeline.add(audioDec)
             pipeline.add(audioConv)
+            pipeline.add(audioResample)
             pipeline.add(audioSink)
 
             fileSrc.link(audioDec)
-            audioConv.link(audioSink)
+            audioConv.link(audioResample)
+            audioResample.link(audioSink)
 
             audioDec.connect("pad-added", self._GstPadAdded, audioConv)
 
@@ -107,40 +109,47 @@ class GPlayer:
             bus.add_signal_watch()
             bus.connect("message", self._GstOnMessage)
 
-        gtkMainloopThread = threading.Thread(name="gtkMainLoop",
-                                             target=self._GtkMainloop)
-        gtkMainloopThread.start()
+        GMainLoop.EnsureRunning()
 
     def Stop(self):
         self.Close()
 
     def Close(self):
-        self.__pipeline.send_event(Gst.Event.new_eos())
+        if self.__pipeline:
+            self.__pipeline.send_event(Gst.Event.new_eos())
 
     def GetLength(self):
         return self.__length
 
+    def GetPosition(self):
+        if self.__pipeline:
+            hasResult, position = self.__pipeline.query_position(Gst.Format.TIME)
+            if hasResult:
+                return position // Gst.MSECOND
+
+    def SetPosition(self, start):
+        if self.__pipeline:
+            nanoSecs = start * Gst.MSECOND
+            self.__pipeline.seek(1.0, Gst.Format.TIME,
+                          Gst.SeekFlags.FLUSH, Gst.SeekType.SET,
+                          nanoSecs,
+                          Gst.SeekType.NONE, 0)
+
     def _GstOnMessage(self, bus, msg):  # pylint: disable=unused-argument
-        logging.debug('_GstOnMessage: %s', msg.type)
+        self.__log(logging.DEBUG, '_GstOnMessage: %s', msg.type)
 
         if msg.type == Gst.MessageType.ERROR:
             err, debug = msg.parse_error()
-            logging.error("Error received from element %s: %s",
-                          msg.src.get_name(), err)
-            logging.debug("Debugging information: %s", debug)
+            self.__log(logging.ERROR, "Error received from element %s: %s",
+                       msg.src.get_name(), err)
+            self.__log(logging.DEBUG, "Debugging information: %s", debug)
 
         elif msg.type == Gst.MessageType.EOS:
             self.__pipeline.set_state(Gst.State.NULL)
-            self.__gtkMainloop.quit()
             self.__pipeline = None
-            self.__gtkMainloop = None
 
     def _GstPadAdded(self, decodebin, pad, audioConv):  # pylint: disable=unused-argument
         caps = pad.get_current_caps()
         compatible_pad = audioConv.get_compatible_pad(pad, caps)
-        pad.link(compatible_pad)
-
-    def _GtkMainloop(self):
-        GObject.threads_init()
-        self.__gtkMainloop = GObject.MainLoop()
-        self.__gtkMainloop.run()
+        if compatible_pad:
+            pad.link(compatible_pad)
