@@ -13,12 +13,14 @@ import queue
 
 from gi.repository import Gst
 from gi.repository import GObject
+from gi.repository import Pango
 
-from photofilmstrip.core.Aspect import Aspect
 from photofilmstrip.core.OutputProfile import OutputProfile
 from photofilmstrip.core.BaseRenderer import BaseRenderer
 from photofilmstrip.core.Subtitle import SrtParser
 from photofilmstrip.core.exceptions import RendererException
+from photofilmstrip.core.GMainLoop import GMainLoop
+from photofilmstrip.core.Aspect import Aspect
 
 
 class _GStreamerRenderer(BaseRenderer):
@@ -34,20 +36,22 @@ class _GStreamerRenderer(BaseRenderer):
         self.pipeline = None
         self.idxFrame = 0
         self.idxAudioFile = 0
+        self.idxSub = 0
         self.imgDuration = None
         self.finalTime = None
-        self.gtkMainloop = None
         self.textoverlay = None
         self.srtParse = None
         self.concat = None
         self.ptsOffset = 0
         self.ptsLast = -1
 
+        self.usePangoSubtitle = False
+
     @staticmethod
     def CheckDependencies(msgList):
         if Gst is None or GObject is None:
             _GStreamerRenderer.Log(logging.DEBUG, "checking for gstreamer failed!")
-            msgList.append(_(u"GStreamer (python-gst-1.0) required!"))
+            msgList.append(_("GStreamer (python-gst-1.0) required!"))
         else:
             to = Gst.ElementFactory.find("textoverlay")
             if to is None:
@@ -55,14 +59,17 @@ class _GStreamerRenderer(BaseRenderer):
 
     @staticmethod
     def GetProperties():
-        return ["Bitrate", "RenderSubtitle", "SubtitleSettings"]
+        return ["Bitrate",
+                "Subtitle", "SubtitleSettings", "SubtitleLanguage"]
 
     @staticmethod
     def GetDefaultProperty(prop):
-        if prop == "RenderSubtitle":
-            return "false"
+        if prop == "Subtitle":
+            return "file"
         if prop == "SubtitleSettings":
             return ""
+        if prop == "SubtitleLanguage":
+            return "en"
         return BaseRenderer.GetDefaultProperty(prop)
 
     def ToSink(self, data):
@@ -83,7 +90,6 @@ class _GStreamerRenderer(BaseRenderer):
 
         self._Log(logging.DEBUG, "waiting for ready event")
         self.ready.wait()
-        self.gtkMainloop.quit()
 
         self.active = None
         self.finished = None
@@ -91,21 +97,28 @@ class _GStreamerRenderer(BaseRenderer):
         self.pipeline = None
         self.idxFrame = 0
         self.idxAudioFile = 0
+        self.idxSub = 0
         self.imgDuration = None
         self.finalTime = None
-        self.gtkMainloop = None
         self.textoverlay = None
         self.srtParse = None
         self.concat = None
         self.ptsOffset = 0
         self.ptsLast = -1
 
-        if self.GetTypedProperty("RenderSubtitle", bool):
+        if self.GetTypedProperty("Subtitle", str) != "file":
             # delete subtitle file, if subtitle is rendered in video
-            srtPath = self._outFile + ".srt"
-            if os.path.exists(srtPath):
+            srtPath = self._GetSubtitleFile()
+            if srtPath:
                 os.remove(srtPath)
 
+    def _GetSubtitleFile(self):
+        srtPath = self._outFile + ".srt"
+        if os.path.exists(srtPath):
+            return srtPath
+        else:
+            return None
+
     def ProcessAbort(self):
         '''
         Called if the user aborts the rendering. Sets the active flag to false
@@ -134,8 +147,13 @@ class _GStreamerRenderer(BaseRenderer):
 
         self.pipeline = Gst.Pipeline()
 
-        caps = Gst.caps_from_string(
-            "image/jpeg,framerate={0}".format(frameRate.AsStr()))
+        if self.GetProfile().IsMPEGProfile():
+            caps = Gst.caps_from_string(
+                "image/jpeg,framerate={0},pixel-aspect-ratio={1}".format(
+                    frameRate.AsStr(), Aspect.AsStr(self._aspect)))
+        else:
+            caps = Gst.caps_from_string(
+                "image/jpeg,framerate={0}".format(frameRate.AsStr()))
         videoSrc = Gst.ElementFactory.make("appsrc")
         videoSrc.set_property("block", True)
         videoSrc.set_property("caps", caps)
@@ -154,20 +172,34 @@ class _GStreamerRenderer(BaseRenderer):
         videoEnc = self._GetVideoEncoder()
         self.pipeline.add(videoEnc)
 
-        if self.GetTypedProperty("RenderSubtitle", bool) and Gst.ElementFactory.find("textoverlay"):
-            self.textoverlay = Gst.ElementFactory.make("textoverlay")
-            self.textoverlay.set_property("text", "")
-            self._SetupTextOverlay()
-            self.pipeline.add(self.textoverlay)
+        muxSubtitle = False
+        subtitleEnc = None
+        if self._GetSubtitleFile():
+            self.srtParse = SrtParser(
+                self._GetSubtitleFile(),
+                self.GetProfile().GetFrameRate().AsFloat())
+            if self.GetTypedProperty("Subtitle", str) == "render" and Gst.ElementFactory.find("textoverlay"):
+                self.textoverlay = Gst.ElementFactory.make("textoverlay")
+                self.textoverlay.set_property("text", "")
+                self._SetupTextOverlay()
+                self.pipeline.add(self.textoverlay)
+            elif self.GetTypedProperty("Subtitle", str) == "embed":
+                muxSubtitle = True
+                subtitleEnc = self._GetSubtitleEncoder()  # pylint: disable=assignment-from-none
+
+        vcaps = None
+        if self.GetProfile().IsMPEGProfile():
+            vcaps = Gst.caps_from_string(
+                "video/x-raw,format=I420")
 
         # link elements for video stream
         videoSrc.link(jpegDecoder)
         jpegDecoder.link(colorConverter)
         if self.textoverlay:
-            colorConverter.link(self.textoverlay)
+            colorConverter.link_filtered(self.textoverlay, vcaps)
             self.textoverlay.link(queueVideo)
         else:
-            colorConverter.link(queueVideo)
+            colorConverter.link_filtered(queueVideo, vcaps)
         queueVideo.link(videoEnc)
 
         audioEnc = None
@@ -209,8 +241,9 @@ class _GStreamerRenderer(BaseRenderer):
                 self.pipeline.add(ap)
                 audioEnc.link(ap)
                 audioEnc = ap
-        elif isinstance(self, MkvX265AC3):
+        elif isinstance(self, Mp4X265AAC):
             vp = Gst.ElementFactory.make("h265parse")
+            vp.set_property("config-interval", -1)
             self.pipeline.add(vp)
             videoEnc.link(vp)
             videoEnc = vp
@@ -234,6 +267,34 @@ class _GStreamerRenderer(BaseRenderer):
             audioEnc.link(audioQueue2)
             audioQueue2.link(mux)
 
+        if muxSubtitle:
+            subCaps = self._GetSubtitleEncoderCaps()
+            subPad = None
+            if subCaps:
+                subPad = mux.get_request_pad("subtitle_%u")
+            if subPad:
+                # muxer has subtitle pad, so initialize subtitle processing
+                self.usePangoSubtitle = subCaps.find("pango-markup") != -1
+
+                subSrc = Gst.ElementFactory.make("appsrc")
+                subCaps = Gst.caps_from_string(subCaps)
+                subSrc.set_property("caps", subCaps)
+                subSrc.set_property("format", Gst.Format.TIME)
+                subSrc.connect("need-data", self._GstNeedSubtitleData)
+                self.pipeline.add(subSrc)
+
+                if subtitleEnc:
+                    self.pipeline.add(subtitleEnc)
+                    subSrc.link(subtitleEnc)
+                    srcPad = subtitleEnc.get_static_pad("src")
+                else:
+                    srcPad = subSrc.get_static_pad("src")
+
+                srcPad.link(subPad)
+            else:
+                self._Log(logging.WARNING,
+                          "Want to mux subtitle but container does not support it!")
+
         sink = Gst.ElementFactory.make("filesink")
         sink.set_property("location", self.GetOutputFile())
         self.pipeline.add(sink)
@@ -246,18 +307,10 @@ class _GStreamerRenderer(BaseRenderer):
 
         self.pipeline.set_state(Gst.State.PLAYING)
 
-        self.gtkMainloop = GObject.MainLoop()
-        gtkMainloopThread = threading.Thread(name="gtkMainLoop",
-                                             target=self._GtkMainloop)
-        gtkMainloopThread.start()
+        GMainLoop.EnsureRunning()
 
         self.ready.clear()
 
-    def _GtkMainloop(self):
-        self._Log(logging.DEBUG, "GTK mainloop starting...")
-        self.gtkMainloop.run()
-        self._Log(logging.DEBUG, "GTK mainloop finished")
-
     def _GstAddAudioFile(self, audioFile):
         '''
         Inserts new elements to refer a new audio file in the gstreamer pipeline.
@@ -284,7 +337,7 @@ class _GStreamerRenderer(BaseRenderer):
         bitrate = self.GetTypedProperty("Bitrate", int,
                                         self.GetProfile().GetBitrate())
         if bitrate is None:
-            raise RendererException(_(u"Bitrate must be a number!"))
+            raise RendererException(_("Bitrate must be a number!"))
         return bitrate
 
     def _GstOnMessage(self, bus, msg):  # pylint: disable=unused-argument
@@ -355,16 +408,61 @@ class _GStreamerRenderer(BaseRenderer):
 
         if self.textoverlay:
 #             self.textoverlay.set_property("text", "Frame: %s" % self.idxFrame)
-            if self.srtParse is None:
-                srtPath = self._outFile + ".srt"
-                self.srtParse = SrtParser(
-                    srtPath, self.GetProfile().GetFrameRate().AsFloat())
-
             subtitle = self.srtParse.Get(self.idxFrame)
-            self.textoverlay.set_property("text", subtitle)
+            escaped_subtitle = self._GetPangoEscapedSubtitle(subtitle)
+
+            self.textoverlay.set_property("text", escaped_subtitle)
 
         self.idxFrame += 1
 
+    def _GetPangoEscapedSubtitle(self, text, rawText=False):
+        try:
+            parseResult = Pango.parse_markup(text, -1, "&")
+            if rawText:
+                return parseResult.text
+            else:
+                return text
+        except GObject.GError as err:
+            if rawText:
+                return text
+
+            text_escaped = GObject.markup_escape_text(text)
+            if err.domain != "g-markup-error-quark":  # pylint: disable=no-member
+                self._Log(logging.ERROR, "Unexpected error while parsing subtitle '%s' with pango! Using escaped text '%s'", text, text_escaped)
+            else:
+                self._Log(logging.WARNING, "Subtitle '%s' is not well formed pango markup. Using escaped text '%s'", text, text_escaped)
+            return text_escaped
+
+    def _GstNeedSubtitleData(self, src, need_bytes):  # pylint: disable=unused-argument
+        self._Log(logging.DEBUG,
+                  "_GstNeedSubtitleData: %s, pango=%s",
+                  self.idxSub, self.usePangoSubtitle)
+        while 1:
+            subtitle, start, duration = self.srtParse.GetByIndex(self.idxSub)
+            if start is not None and not subtitle:
+                self._Log(
+                    logging.WARNING,
+                    "_GstNeedSubtitleData: skipping empty subtitle: %s-%s",
+                    start, duration)
+                self.idxSub += 1
+            else:
+                break
+        if duration is None:
+            src.emit("end-of-stream")
+            return
+        else:
+            subtitle = self._GetPangoEscapedSubtitle(
+                subtitle, not self.usePangoSubtitle)
+
+            subText = subtitle.encode()
+            subBuf = Gst.Buffer.new_allocate(None, len(subText), None)
+            subBuf.fill(0, subText)
+            subBuf.pts = subBuf.dts = start * Gst.MSECOND
+            subBuf.duration = duration * Gst.MSECOND
+            src.emit("push-buffer", subBuf)
+
+        self.idxSub += 1
+
     def _GstPadAddedAudio(self, decodebin, pad):
         '''
         Gstreamer pad-added probe callback to attach a new audio file to the
@@ -439,6 +537,12 @@ class _GStreamerRenderer(BaseRenderer):
     def _GetVideoEncoderCaps(self):
         return None
 
+    def _GetSubtitleEncoder(self):
+        return None
+
+    def _GetSubtitleEncoderCaps(self):
+        return "text/x-raw,format=(string)utf8"
+
 
 class MkvX264AC3(_GStreamerRenderer):
 
@@ -452,15 +556,15 @@ class MkvX264AC3(_GStreamerRenderer):
         if not msgList:
             aEnc = Gst.ElementFactory.find("avenc_ac3")
             if aEnc is None:
-                msgList.append(_(u"libav (gstreamer1.0-libav) required!"))
+                msgList.append(_("libav (gstreamer1.0-libav) required!"))
 
             vEnc = Gst.ElementFactory.find("x264enc")
             if vEnc is None:
-                msgList.append(_(u"x264-Codec (gstreamer1.0-plugins-ugly) required!"))
+                msgList.append(_("x264-Codec (gstreamer1.0-plugins-ugly) required!"))
 
             mux = Gst.ElementFactory.find("matroskamux")
             if mux is None:
-                msgList.append(_(u"MKV-Muxer (gstreamer1.0-plugins-good) required!"))
+                msgList.append(_("MKV-Muxer (gstreamer1.0-plugins-good) required!"))
 
     @staticmethod
     def GetDefaultProperty(prop):
@@ -484,11 +588,7 @@ class MkvX264AC3(_GStreamerRenderer):
         return mux
 
     def _GetAudioEncoder(self):
-#         audioEnc = Gst.ElementFactory.make("lamemp3enc")
         audioEnc = Gst.ElementFactory.make("avenc_ac3")
-#         audioEnc = Gst.ElementFactory.make("lame")
-
-#         audioEnc.set_property("target", "bitrate")
 #         audioEnc.set_property("bitrate", 192)
         return audioEnc
 
@@ -515,6 +615,17 @@ class MkvX264AC3(_GStreamerRenderer):
                       profile)
         return None
 
+    def _GetSubtitleEncoder(self):
+        kateEnc = Gst.ElementFactory.make("kateenc")
+        if kateEnc:
+            kateEnc.set_property("category", "SUB")
+            kateEnc.set_property("language",
+                                 self.GetTypedProperty("SubtitleLanguage", str))
+        return kateEnc
+
+    def _GetSubtitleEncoderCaps(self):
+        return "text/x-raw,format=(string)pango-markup"
+
 
 class Mp4X264AAC(_GStreamerRenderer):
 
@@ -528,15 +639,15 @@ class Mp4X264AAC(_GStreamerRenderer):
         if not msgList:
             aEnc = Gst.ElementFactory.find("avenc_aac")
             if aEnc is None:
-                msgList.append(_(u"libav (gstreamer1.0-libav) required!"))
+                msgList.append(_("libav (gstreamer1.0-libav) required!"))
 
             vEnc = Gst.ElementFactory.find("x264enc")
             if vEnc is None:
-                msgList.append(_(u"x264-Codec (gstreamer1.0-plugins-ugly) required!"))
+                msgList.append(_("x264-Codec (gstreamer1.0-plugins-ugly) required!"))
 
             mux = Gst.ElementFactory.find("mp4mux")
             if mux is None:
-                msgList.append(_(u"MP4-Muxer (gstreamer1.0-plugins-good) required!"))
+                msgList.append(_("MP4-Muxer (gstreamer1.0-plugins-good) required!"))
 
     @staticmethod
     def GetDefaultProperty(prop):
@@ -586,41 +697,41 @@ class Mp4X264AAC(_GStreamerRenderer):
         return None
 
 
-class MkvX265AC3(_GStreamerRenderer):
+class Mp4X265AAC(_GStreamerRenderer):
 
     @staticmethod
     def GetName():
-        return "x265/AC3 (MKV)"
+        return "x265/AAC (MP4)"
 
     @staticmethod
     def CheckDependencies(msgList):
         _GStreamerRenderer.CheckDependencies(msgList)
         if not msgList:
-            aEnc = Gst.ElementFactory.find("avenc_ac3")
+            aEnc = Gst.ElementFactory.find("avenc_aac")
             if aEnc is None:
-                msgList.append(_(u"libav (gstreamer1.0-libav) required!"))
+                msgList.append(_("libav (gstreamer1.0-libav) required!"))
 
             vEnc = Gst.ElementFactory.find("x265enc")
             if vEnc is None:
-                msgList.append(_(u"x264-Codec (gstreamer1.0-plugins-ugly) required!"))
+                msgList.append(_("x265-Codec (gstreamer1.0-plugins-ugly) required!"))
 
-            mux = Gst.ElementFactory.find("matroskamux")
+            mux = Gst.ElementFactory.find("qtmux")
             if mux is None:
-                msgList.append(_(u"MKV-Muxer (gstreamer1.0-plugins-good) required!"))
+                msgList.append(_("MKV-Muxer (gstreamer1.0-plugins-good) required!"))
 
     @staticmethod
     def GetProperties():
         return _GStreamerRenderer.GetProperties() + ["SpeedPreset"]
 
     def _GetExtension(self):
-        return "mkv"
+        return "mp4"
 
     def _GetMux(self):
-        mux = Gst.ElementFactory.make("matroskamux")
+        mux = Gst.ElementFactory.make("qtmux")
         return mux
 
     def _GetAudioEncoder(self):
-        audioEnc = Gst.ElementFactory.make("avenc_ac3")
+        audioEnc = Gst.ElementFactory.make("avenc_aac")
         return audioEnc
 
     def _GetVideoEncoder(self):
@@ -644,15 +755,15 @@ class OggTheoraVorbis(_GStreamerRenderer):
         if not msgList:
             aEnc = Gst.ElementFactory.find("theoraenc")
             if aEnc is None:
-                msgList.append(_(u"Theora-Codec (gstreamer1.0-plugins-base) required!"))
+                msgList.append(_("Theora-Codec (gstreamer1.0-plugins-base) required!"))
 
             vEnc = Gst.ElementFactory.find("vorbisenc")
             if vEnc is None:
-                msgList.append(_(u"Vorbis-Codec (gstreamer1.0-plugins-base) required!"))
+                msgList.append(_("Vorbis-Codec (gstreamer1.0-plugins-base) required!"))
 
             mux = Gst.ElementFactory.find("oggmux")
             if mux is None:
-                msgList.append(_(u"OGV-Muxer (gstreamer1.0-plugins-base) required!"))
+                msgList.append(_("OGV-Muxer (gstreamer1.0-plugins-base) required!"))
 
     def _GetExtension(self):
         return "ogv"
@@ -670,6 +781,17 @@ class OggTheoraVorbis(_GStreamerRenderer):
         videoEnc.set_property("bitrate", self._GetBitrate())
         return videoEnc
 
+    def _GetSubtitleEncoder(self):
+        kateEnc = Gst.ElementFactory.make("kateenc")
+        if kateEnc:
+            kateEnc.set_property("category", "SUB")
+            kateEnc.set_property("language",
+                                 self.GetTypedProperty("SubtitleLanguage", str))
+        return kateEnc
+
+    def _GetSubtitleEncoderCaps(self):
+        return "text/x-raw,format=(string)pango-markup"
+
 
 class VCDFormat(_GStreamerRenderer):
 
@@ -681,35 +803,44 @@ class VCDFormat(_GStreamerRenderer):
     def CheckDependencies(msgList):
         _GStreamerRenderer.CheckDependencies(msgList)
         if not msgList:
-            vEnc = Gst.ElementFactory.find("mpeg2enc")
+            vEnc = Gst.ElementFactory.find("avenc_mpeg2video")
             if vEnc is None:
-                msgList.append(_(u"MPEG-1/2-Codec (gstreamer1.0-plugins-bad) required!"))
+                msgList.append(_("MPEG-1/2-Codec (gstreamer1.0-libav) required!"))
 
             aEnc = Gst.ElementFactory.find("avenc_mp2")
             if aEnc is None:
-                msgList.append(_(u"libav (gstreamer1.0-libav) required!"))
+                msgList.append(_("libav (gstreamer1.0-libav) required!"))
 
-            mux = Gst.ElementFactory.find("mpegtsmux")
+            mux = Gst.ElementFactory.find("mpegpsmux")
             if mux is None:
-                msgList.append(_(u"MPEG-Muxer (gstreamer1.0-plugins-bad) required!"))
+                msgList.append(_("MPEG-Muxer (gstreamer1.0-plugins-bad) required!"))
 
     def _GetExtension(self):
         return "mpg"
 
     def _GetMux(self):
-        mux = Gst.ElementFactory.make("mpegtsmux")
+        # mux = Gst.ElementFactory.make("avmux_vcd")
+        mux = Gst.ElementFactory.make("mpegpsmux")
         return mux
 
     def _GetAudioEncoder(self):
         audioEnc = Gst.ElementFactory.make("avenc_mp2")
+        audioEnc.set_property("bitrate", 224000)
+        audioEnc.set_property("ar", 44100)
         return audioEnc
 
     def _GetVideoEncoder(self):
-        videoEnc = Gst.ElementFactory.make("mpeg2enc")
-        videoEnc.set_property("format", 1)
-        videoEnc.set_property("norm", "p" if self.GetProfile().GetVideoNorm() == OutputProfile.PAL else "n")
+        videoEnc = Gst.ElementFactory.make("avenc_mpeg1video")
+        videoEnc.set_property("bitrate", self._GetBitrate() * 1000)
+        if self.GetProfile().GetVideoNorm() == OutputProfile.PAL:
+            videoEnc.set_property("gop-size", 15)
+        else:
+            videoEnc.set_property("gop-size", 18)
         return videoEnc
 
+    def _GetSubtitleEncoderCaps(self):
+        return None
+
 
 class SVCDFormat(_GStreamerRenderer):
 
@@ -721,44 +852,47 @@ class SVCDFormat(_GStreamerRenderer):
     def CheckDependencies(msgList):
         _GStreamerRenderer.CheckDependencies(msgList)
         if not msgList:
-            vEnc = Gst.ElementFactory.find("mpeg2enc")
+            vEnc = Gst.ElementFactory.find("avenc_mpeg2video")
             if vEnc is None:
-                msgList.append(_(u"MPEG-1/2-Codec (gstreamer1.0-plugins-bad) required!"))
+                msgList.append(_("MPEG-1/2-Codec (gstreamer1.0-libav) required!"))
 
             aEnc = Gst.ElementFactory.find("avenc_mp2")
             if aEnc is None:
-                msgList.append(_(u"libav (gstreamer1.0-libav) required!"))
+                msgList.append(_("libav (gstreamer1.0-libav) required!"))
 
-            mux = Gst.ElementFactory.find("mpegtsmux")
+            mux = Gst.ElementFactory.find("mpegpsmux")
             if mux is None:
-                msgList.append(_(u"MPEG-Muxer (gstreamer1.0-plugins-bad) required!"))
+                msgList.append(_("MPEG-Muxer (gstreamer1.0-plugins-bad) required!"))
 
     def _GetExtension(self):
         return "mpg"
 
     def _GetMux(self):
-        mux = Gst.ElementFactory.make("mpegtsmux")
+        # mux = Gst.ElementFactory.make("avmux_svcd")
+        mux = Gst.ElementFactory.make("mpegpsmux")
         return mux
 
     def _GetAudioEncoder(self):
         audioEnc = Gst.ElementFactory.make("avenc_mp2")
+        audioEnc.set_property("bitrate", 256000)
+        audioEnc.set_property("ar", 44100)
         return audioEnc
 
     def _GetVideoEncoder(self):
-        videoEnc = Gst.ElementFactory.make("mpeg2enc")
-        videoEnc.set_property("format", 4)
-        videoEnc.set_property("norm", "p" if self.GetProfile().GetVideoNorm() == OutputProfile.PAL else "n")
-        if self._aspect == Aspect.ASPECT_16_9:
-            gstAspect = 3
-        elif self._aspect == Aspect.ASPECT_4_3:
-            gstAspect = 2
+        videoEnc = Gst.ElementFactory.make("avenc_mpeg2video")
+        videoEnc.set_property("bitrate", self._GetBitrate() * 1000)
+        if self.GetProfile().GetVideoNorm() == OutputProfile.PAL:
+            videoEnc.set_property("video-format", 1)
+            videoEnc.set_property("gop-size", 12)
         else:
-            gstAspect = 0
-        videoEnc.set_property("aspect", gstAspect)
-        videoEnc.set_property("dummy-svcd-sof", 0)
-        videoEnc.set_property("bitrate", self._GetBitrate())
+            videoEnc.set_property("video-format", 2)
+            videoEnc.set_property("gop-size", 15)
+        videoEnc.set_property("scan-offset", 1)
         return videoEnc
 
+    def _GetSubtitleEncoderCaps(self):
+        return None
+
 
 class DVDFormat(_GStreamerRenderer):
 
@@ -770,39 +904,38 @@ class DVDFormat(_GStreamerRenderer):
     def CheckDependencies(msgList):
         _GStreamerRenderer.CheckDependencies(msgList)
         if not msgList:
-            vEnc = Gst.ElementFactory.find("mpeg2enc")
+            vEnc = Gst.ElementFactory.find("avenc_mpeg2video")
             if vEnc is None:
-                msgList.append(_(u"MPEG-1/2-Codec (gstreamer1.0-plugins-bad) required!"))
+                msgList.append(_("MPEG-1/2-Codec (gstreamer1.0-libav) required!"))
 
             aEnc = Gst.ElementFactory.find("avenc_mp2")
             if aEnc is None:
-                msgList.append(_(u"libav (gstreamer1.0-libav) required!"))
+                msgList.append(_("libav (gstreamer1.0-libav) required!"))
 
-            mux = Gst.ElementFactory.find("mpegtsmux")
+            mux = Gst.ElementFactory.find("mpegpsmux")
             if mux is None:
-                msgList.append(_(u"MPEG-Muxer (gstreamer1.0-plugins-bad) required!"))
+                msgList.append(_("MPEG-Muxer (gstreamer1.0-plugins-bad) required!"))
 
     def _GetExtension(self):
         return "mpg"
 
     def _GetMux(self):
-        mux = Gst.ElementFactory.make("mpegtsmux")
+        # mux = Gst.ElementFactory.make("avmux_dvd")
+        mux = Gst.ElementFactory.make("mpegpsmux")
         return mux
 
     def _GetAudioEncoder(self):
         audioEnc = Gst.ElementFactory.make("avenc_mp2")
+        audioEnc.set_property("bitrate", 256000)
+        audioEnc.set_property("ar", 48000)
         return audioEnc
 
     def _GetVideoEncoder(self):
-        videoEnc = Gst.ElementFactory.make("mpeg2enc")
-        videoEnc.set_property("format", 8)
-        videoEnc.set_property("norm", "p" if self.GetProfile().GetVideoNorm() == OutputProfile.PAL else "n")
-        if self._aspect == Aspect.ASPECT_16_9:
-            gstAspect = 3
-        elif self._aspect == Aspect.ASPECT_4_3:
-            gstAspect = 2
-        else:
-            gstAspect = 0
-        videoEnc.set_property("aspect", gstAspect)
-        videoEnc.set_property("bitrate", self._GetBitrate())
+        videoEnc = Gst.ElementFactory.make("avenc_mpeg2video")
+        videoEnc.set_property("video-format", 1 if self.GetProfile().GetVideoNorm() == OutputProfile.PAL else 2)
+        videoEnc.set_property("bitrate", self._GetBitrate() * 1000)
+        videoEnc.set_property("gop-size", 15)
         return videoEnc
+
+    def _GetSubtitleEncoderCaps(self):
+        return None
