@@ -1,24 +1,9 @@
-# Boa:Frame:FrmMain
-# encoding: UTF-8
+# -*- coding: utf-8 -*-
 #
 # PhotoFilmStrip - Creates movies out of your pictures.
 #
 # Copyright (C) 2008 Jens Goepfert
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
 
 import os
 
@@ -32,6 +17,8 @@ from photofilmstrip import Constants
 from photofilmstrip.action.ActionI18N import ActionI18N
 
 from photofilmstrip.core.RenderJob import RenderJob
+from photofilmstrip.core.Story import Story
+from photofilmstrip.core.StoryFile import StoryFile
 
 from photofilmstrip.lib.common.ObserverPattern import Observer
 from photofilmstrip.lib.Settings import Settings
@@ -44,13 +31,15 @@ from photofilmstrip.lib.jobimpl.PnlJobManager import PnlJobManager
 from photofilmstrip.gui.ActionManager import ActionManager
 from photofilmstrip.gui.PnlWelcome import PnlWelcome
 from photofilmstrip.gui.HelpViewer import HelpViewer
-from photofilmstrip.gui.DlgProjectProps import DlgProjectProps
-from photofilmstrip.gui.PnlPfsProject import PnlPfsProject
+from photofilmstrip.gui.DlgNewProject import DlgNewProject
 from photofilmstrip.gui.WxProjectFile import WxProjectFile
 from photofilmstrip.gui.PnlRenderJobVisual import PnlRenderJobVisual
+from photofilmstrip.gui.PnlStory import PnlStory
 from photofilmstrip.gui.PnlEditorPage import PnlEditorPage
 
 from photofilmstrip.res.license import licenseText
+from photofilmstrip.gui.PnlTimelapse import PnlTimelapse
+from photofilmstrip.gui.PnlSlideshow import PnlSlideshow
 
 ID_PAGE_UP = wx.NewId()
 ID_PAGE_DOWN = wx.NewId()
@@ -59,7 +48,7 @@ ID_PAGE_DOWN = wx.NewId()
 class FrmMain(wx.Frame, Observer, WxVisualJobManager):
 
     def __init__(self):
-        wx.Frame.__init__(self, None, -1, name=u'FrmMain',
+        wx.Frame.__init__(self, None, -1, name="FrmMain",
               pos=wx.Point(-1, -1), size=wx.Size(-1, -1),
               style=wx.DEFAULT_FRAME_STYLE | wx.TAB_TRAVERSAL)
         WxVisualJobManager.__init__(self)
@@ -94,9 +83,9 @@ class FrmMain(wx.Frame, Observer, WxVisualJobManager):
         self.pnlWelcome = PnlWelcome(self.notebook, self)
         self.pnlWelcome.SetDropTarget(ProjectDropTarget(self))
 
-        self.notebook.AddPage(self.pnlWelcome, _(u"Welcome"), True)
+        self.notebook.AddPage(self.pnlWelcome, _("Welcome"), True)
 
-        self.frmJobManager = wx.Frame(self, -1, _(u"Job queue"),
+        self.frmJobManager = wx.Frame(self, -1, _("Job queue"),
                                       size=wx.Size(600, 400),
                                       style=wx.DEFAULT_FRAME_STYLE | wx.STAY_ON_TOP)
         self.frmJobManager.SetIcon(wx.ArtProvider.GetIcon("PFS_JOB_QUEUE_16", wx.ART_OTHER))
@@ -105,7 +94,9 @@ class FrmMain(wx.Frame, Observer, WxVisualJobManager):
 
         self.Bind(wx.EVT_CLOSE, self.OnClose)
 
-        self.Bind(wx.EVT_MENU, self.OnProjectNew, id=wx.ID_NEW)
+        self.Bind(wx.EVT_MENU, self.OnSlideshow, id=ActionManager.ID_SLIDESHOW)
+        self.Bind(wx.EVT_MENU, self.OnTimelapse, id=ActionManager.ID_TIMELAPSE)
+        self.Bind(wx.EVT_MENU, self.OnStory, id=ActionManager.ID_STORY)
         self.Bind(wx.EVT_MENU, self.OnProjectLoad, id=wx.ID_OPEN)
         self.Bind(wx.EVT_MENU, self.OnProjectSave, id=wx.ID_SAVE)
         self.Bind(wx.EVT_MENU, self.OnProjectSaveAs, id=wx.ID_SAVEAS)
@@ -151,7 +142,7 @@ class FrmMain(wx.Frame, Observer, WxVisualJobManager):
     def OnRegisterJob(self, event):
         job = event.GetJob()
         if isinstance(job, RenderJob):
-            self.statusBar.SetStatusText(_(u"Rendering in progress..."), 3)
+            self.statusBar.SetStatusText(_("Rendering in progress..."), 3)
 
     def OnRemoveJob(self, event):
         self.statusBar.SetStatusText("", 3)
@@ -174,7 +165,7 @@ class FrmMain(wx.Frame, Observer, WxVisualJobManager):
             self.notebook.SetWindowStyleFlag(wx.aui.AUI_NB_CLOSE_ON_ACTIVE_TAB)
 
             filepath = page.GetProject().GetFilename()
-            self.SetTitle(Constants.APP_NAME + u' - ' + filepath)
+            self.SetTitle(Constants.APP_NAME + ' - ' + filepath)
 
         self._actionMgr.UpdateActions(page)
         self.UpdateStatusText()
@@ -216,9 +207,19 @@ class FrmMain(wx.Frame, Observer, WxVisualJobManager):
 
 # Misc
     def OnStatusBarLeftDown(self, event):
-        if self.statusBar.GetFieldRect(3).Contains(event.GetPosition()) \
+        mpos = event.GetPosition()
+
+        if self.statusBar.GetFieldRect(3).Contains(mpos) \
         and self.statusBar.GetStatusText(3) != "":
             self.frmJobManager.Show()
+            return
+
+        pnlEditor = self.__GetCurrentPnlEditor()
+        if pnlEditor:
+            for idx in range(self.statusBar.GetFieldsCount()):
+                if self.statusBar.GetFieldRect(idx).Contains(mpos):
+                    pnlEditor.OnStatusBarClick(idx - 1)
+                    return
 
     def OnClose(self, event):
         while self.notebook.GetPageCount() > 1:
@@ -233,17 +234,29 @@ class FrmMain(wx.Frame, Observer, WxVisualJobManager):
         event.Skip()
 
 # Menu
-    def OnProjectNew(self, event):
-        dlg = DlgProjectProps(self)
+    def OnSlideshow(self, event):
+        dlg = DlgNewProject(self, _("Create new slideshow"))
         if dlg.ShowModal() == wx.ID_OK:
             photoFilmStrip = dlg.GetProject()
-            self.NewProject(photoFilmStrip)
+            self._NewSlideshow(photoFilmStrip)
         dlg.Destroy()
 
+    def OnTimelapse(self, event):
+        dlg = DlgNewProject(self, _("Create new timelapse"))
+        if dlg.ShowModal() == wx.ID_OK:
+            photoFilmStrip = dlg.GetProject()
+            photoFilmStrip.SetTimelapse(True)
+            self._NewTimelapse(photoFilmStrip)
+        dlg.Destroy()
+
+    def OnStory(self, event):
+        story = Story(_("New Story") + ".pfstory")
+        self._NewStory(story)
+
     def OnProjectLoad(self, event):
-        dlg = wx.FileDialog(self, _(u"Select %s-Project") % Constants.APP_NAME,
+        dlg = wx.FileDialog(self, _("Select %s-Project") % Constants.APP_NAME,
                             Settings().GetProjectPath(), "",
-                            Constants.APP_NAME + u'-' + _(u"Files") + " (*.pfs)|*.pfs",
+                            Constants.APP_NAME + "-" + _("Files") + " (*.pfs;*.pfstory)|*.pfs;*.pfstory",
                             wx.FD_OPEN)
         if dlg.ShowModal() == wx.ID_OK:
             self.LoadProject(dlg.GetPath())
@@ -281,8 +294,8 @@ class FrmMain(wx.Frame, Observer, WxVisualJobManager):
         Settings().SetLanguage(lang)
         ActionI18N().Execute()
         dlg = wx.MessageDialog(self,
-                               _(u"You must restart %s for your new language setting to take effect.") % Constants.APP_NAME,
-                               _(u"Information"),
+                               _("You must restart %s for your new language setting to take effect.") % Constants.APP_NAME,
+                               _("Information"),
                                wx.ICON_INFORMATION | wx.OK)
         dlg.ShowModal()
         dlg.Destroy()
@@ -290,12 +303,12 @@ class FrmMain(wx.Frame, Observer, WxVisualJobManager):
     def OnAbout(self, event):
         info = wx.adv.AboutDialogInfo()
         info.Name = Constants.APP_NAME
-        info.Version = Constants.APP_VERSION_EX
-        info.Copyright = u"(C) 2017 %s" % Constants.DEVELOPERS[0]
+        info.Version = Constants.APP_VERSION_FULL
+        info.Copyright = "(C) 2022 %s" % Constants.DEVELOPERS[0]
         info.Description = wordwrap(_("PhotoFilmStrip creates movies out of your pictures in just 3 steps. First select your photos, customize the motion path and render the video. There are several output possibilities for VCD, SVCD, DVD up to FULL-HD."),
                                     350,
                                     wx.ClientDC(self))
-        info.WebSite = (Constants.APP_URL, "%s %s" % (Constants.APP_NAME, _(u"online")))
+        info.WebSite = (Constants.APP_URL, "%s %s" % (Constants.APP_NAME, _("online")))
         info.Developers = Constants.DEVELOPERS
         info.Translators = Constants.TRANSLATORS
 
@@ -318,6 +331,9 @@ class FrmMain(wx.Frame, Observer, WxVisualJobManager):
         return None
 
     def AddFileToHistory(self, filename):
+        if os.path.splitext(filename)[1].lower() != ".pfs":
+            return
+
         fileList = Settings().GetFileHistory()
         if filename in fileList:
             fileList.remove(filename)
@@ -341,13 +357,27 @@ class FrmMain(wx.Frame, Observer, WxVisualJobManager):
         else:
             return False
 
-    def NewProject(self, project):
-        pnl = PnlPfsProject(self.notebook, project)
+    def _NewSlideshow(self, project):
+        pnl = PnlSlideshow(self.notebook, project)
         project.AddObserver(self)
         filepath = os.path.basename(project.GetFilename())
         self.notebook.AddPage(pnl, os.path.basename(filepath), True)
         return pnl
 
+    def _NewTimelapse(self, project):
+        pnl = PnlTimelapse(self.notebook, project)
+        project.AddObserver(self)
+        filepath = os.path.basename(project.GetFilename())
+        self.notebook.AddPage(pnl, os.path.basename(filepath), True)
+        return pnl
+
+    def _NewStory(self, story):
+        pnl = PnlStory(self.notebook, story)
+        story.AddObserver(self)
+        filepath = os.path.basename(story.GetFilename())
+        self.notebook.AddPage(pnl, os.path.basename(filepath), True)
+        return pnl
+
     def LoadProject(self, filepath, skipHistory=False):
         for idx in range(1, self.notebook.GetPageCount()):
             page = self.notebook.GetPage(idx)
@@ -355,22 +385,35 @@ class FrmMain(wx.Frame, Observer, WxVisualJobManager):
                 self.notebook.SetSelection(idx)
                 return
 
-        prjFile = WxProjectFile(self, filename=filepath)
+        if os.path.splitext(filepath)[1].lower() == ".pfstory":
+            prjFile = StoryFile(filename=filepath)
+        else:
+            prjFile = WxProjectFile(self, filename=filepath)
         result = prjFile.Load()
         if not result:
             dlg = wx.MessageDialog(self,
-                                   _(u"Invalid %(app)s-Project: %(file)s") % {"app": Constants.APP_NAME,
-                                                                              "file": filepath},
-                                   _(u"Error"),
+                                   _("Invalid %(app)s-Project: %(file)s") % {"app": Constants.APP_NAME,
+                                                                             "file": filepath},
+                                   _("Error"),
                                    wx.OK | wx.ICON_ERROR)
             dlg.ShowModal()
             dlg.Destroy()
             return
 
-        photoFilmStrip = prjFile.GetProject()
-        pics = photoFilmStrip.GetPictures()
+        if isinstance(prjFile, StoryFile):
+            pnl = self._NewStory(prjFile.GetStory())
+            pnl.Init()
+            pnl.SetChanged(False)
+            return
+
+        project = prjFile.GetProject()
+        pics = project.GetPictures()
+
+        if project.GetTimelapse():
+            pnl = self._NewTimelapse(project)
+        else:
+            pnl = self._NewSlideshow(project)
 
-        pnl = self.NewProject(photoFilmStrip)
         pnl.InsertPictures(pics)
         pnl.SetChanged(False)
 
