@@ -1,23 +1,9 @@
-# encoding: UTF-8
+# -*- coding: utf-8 -*-
 #
 # PhotoFilmStrip - Creates movies out of your pictures.
 #
 # Copyright (C) 2008 Jens Goepfert
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
 
 import re
 import threading
@@ -133,7 +119,7 @@ class ImageSectionEditor(wx.Panel, Observer):
             newWidth = iw * ry
             self._zoom = ry
 
-        self._imgProxy.Scale(newWidth, newHeight)
+        self._imgProxy.Scale(int(round(newWidth)), int(round(newHeight)))
 
     def __DrawBitmap(self, dc):
         if self._imgProxy.IsOk():
@@ -151,10 +137,10 @@ class ImageSectionEditor(wx.Panel, Observer):
 
     def __SectRectToClientRect(self):
         left, top = self.__GetBmpTopLeft()
-        sectRect = wx.Rect(left + (self._sectRect.GetLeft() * self._zoom),
-                           top + (self._sectRect.GetTop() * self._zoom),
-                           self._sectRect.GetWidth() * self._zoom,
-                           self._sectRect.GetHeight() * self._zoom)
+        sectRect = wx.Rect(left + int(round(self._sectRect.GetLeft() * self._zoom)),
+                           top + int(round(self._sectRect.GetTop() * self._zoom)),
+                           int(round(self._sectRect.GetWidth() * self._zoom)),
+                           int(round(self._sectRect.GetHeight() * self._zoom)))
         return sectRect
 
     def __DrawSection(self, dc):
@@ -163,12 +149,18 @@ class ImageSectionEditor(wx.Panel, Observer):
 
         sectRect = self.__SectRectToClientRect()
 
+        # draw main rectangle
         dc.SetBrush(wx.TRANSPARENT_BRUSH)
         iRect = wx.Rect(sectRect.GetPosition(), sectRect.GetSize())
         dc.SetPen(wx.WHITE_PEN)
         iRect.Inflate(1, 1)
         dc.DrawRectangle(iRect)
 
+        # draw rule of thirds guides
+        ss = sectRect.GetSize()
+        dc.DrawRectangle(wx.Rect(sectRect.GetPosition() + wx.Size((0, ss[1] // 3)), wx.Size((ss[0], ss[1] // 3))))
+        dc.DrawRectangle(wx.Rect(sectRect.GetPosition() + wx.Size((ss[0] // 3, 0)), wx.Size((ss[0] // 3, ss[1]))))
+
         # draw background
         color = wx.Colour(0, 0, 0, 153)
         dc.SetBrush(wx.Brush(color))
@@ -253,8 +245,8 @@ class ImageSectionEditor(wx.Panel, Observer):
 
     def __ClientToImage(self, px, py):
         bmpLeft, bmpTop = self.__GetBmpTopLeft()
-        nx = (px - bmpLeft) / self._zoom
-        ny = (py - bmpTop) / self._zoom
+        nx = int(round((px - bmpLeft) / self._zoom))
+        ny = int(round((py - bmpTop) / self._zoom))
         return nx, ny
 
     def __FindPosition(self, cpx, cpy):
@@ -312,7 +304,7 @@ class ImageSectionEditor(wx.Panel, Observer):
             self.SetCursor(wx.Cursor(wx.CURSOR_SIZENS))
 
         elif position == self.POSITION_INSIDE:
-            self.SetCursor(wx.Cursor(wx.CURSOR_SIZING))
+            self.SetCursor(cursors.GetMOVE())
         else:
             self.SetCursor(wx.Cursor(wx.CURSOR_ARROW))
 
@@ -446,10 +438,10 @@ class ImageSectionEditor(wx.Panel, Observer):
                         ny = self._imgProxy.GetHeight()
 
                 # everything should be ok now
-                self._sectRect.SetX(nx)
-                self._sectRect.SetY(ny)
-                self._sectRect.SetWidth(width)
-                self._sectRect.SetHeight(height)
+                self._sectRect.SetX(int(round(nx)))
+                self._sectRect.SetY(int(round(ny)))
+                self._sectRect.SetWidth(int(round(width)))
+                self._sectRect.SetHeight(int(round(height)))
 #
             self._SendRectChangedEvent()
 
