@@ -1,24 +1,10 @@
 # Boa:FramePanel:PnlEditPicture
-# encoding: UTF-8
+# -*- coding: utf-8 -*-
 #
 # PhotoFilmStrip - Creates movies out of your pictures.
 #
 # Copyright (C) 2008 Jens Goepfert
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
 
 import wx
 
@@ -76,7 +62,7 @@ class PnlEditPicture(wx.Panel):
         parent.Add(self.stMovement, 0, border=0,
               flag=wx.ALIGN_CENTER_VERTICAL)
         parent.Add(self.choiceMovement, 0, border=0,
-              flag=wx.ALIGN_CENTER_VERTICAL)
+              flag=wx.ALIGN_CENTER_VERTICAL | wx.EXPAND)
         parent.Add(self.pnlImgDuration, 0, border=0,
               flag=wx.ALIGN_CENTER_VERTICAL)
         parent.Add(self.stDurationUnit, 0, border=0,
@@ -84,7 +70,7 @@ class PnlEditPicture(wx.Panel):
         parent.Add(self.stTrans, 0, border=0,
               flag=wx.ALIGN_CENTER_VERTICAL)
         parent.Add(self.choiceTrans, 0, border=0,
-              flag=wx.ALIGN_CENTER_VERTICAL)
+              flag=wx.ALIGN_CENTER_VERTICAL | wx.EXPAND)
         parent.Add(self.pnlTransDuration, 0, border=0,
               flag=wx.ALIGN_CENTER_VERTICAL)
         parent.Add(self.stTransUnit, 0, border=0,
@@ -99,7 +85,7 @@ class PnlEditPicture(wx.Panel):
     def _init_coll_szSettingsCtrls_Growables(self, parent):
         # generated method, don't edit
 
-        parent.AddGrowableCol(1)#!!!
+        parent.AddGrowableCol(1)  #!!!
 
     def _init_coll_szSettingsCtrls_Items(self, parent):
         # generated method, don't edit
@@ -147,21 +133,21 @@ class PnlEditPicture(wx.Panel):
 
     def _init_ctrls(self, prnt):
         # generated method, don't edit
-        wx.Panel.__init__(self, id=wxID_PNLEDITPICTURE, name=u'PnlEditPicture',
+        wx.Panel.__init__(self, id=wxID_PNLEDITPICTURE, name="PnlEditPicture",
               parent=prnt, pos=wx.Point(-1, -1), size=wx.Size(-1, -1),
               style=wx.TAB_TRAVERSAL)
         self.SetClientSize(wx.Size(827, 137))
 
         self.stSettings = wx.StaticText(id=wxID_PNLEDITPICTURESTSETTINGS,
-              label=_(u'Settings'), name=u'stSettings', parent=self,
+              label=_("Settings"), name="stSettings", parent=self,
               pos=wx.Point(-1, -1), size=wx.Size(-1, -1), style=0)
 
         self.stRotation = wx.StaticText(id=wxID_PNLEDITPICTURESTROTATION,
-              label=_(u'Rotation:'), name=u'stRotation', parent=self,
+              label=_("Rotation:"), name="stRotation", parent=self,
               pos=wx.Point(-1, -1), size=wx.Size(-1, -1), style=0)
 
         self.cmdRotateLeft = wx.BitmapButton(bitmap=wx.ArtProvider.GetBitmap('PFS_IMAGE_ROTATION_LEFT_16'),
-              id=wxID_PNLEDITPICTURECMDROTATELEFT, name=u'cmdRotateLeft',
+              id=wxID_PNLEDITPICTURECMDROTATELEFT, name="cmdRotateLeft",
               parent=self, pos=wx.Point(-1, -1), size=wx.Size(-1, -1),
               style=wx.BU_AUTODRAW)
         self.cmdRotateLeft.SetBitmapDisabled(wx.ArtProvider.GetBitmap('PFS_IMAGE_ROTATION_LEFT_D_16'))
@@ -169,7 +155,7 @@ class PnlEditPicture(wx.Panel):
               id=wxID_PNLEDITPICTURECMDROTATELEFT)
 
         self.cmdRotateRight = wx.BitmapButton(bitmap=wx.ArtProvider.GetBitmap('PFS_IMAGE_ROTATION_RIGHT_16'),
-              id=wxID_PNLEDITPICTURECMDROTATERIGHT, name=u'cmdRotateRight',
+              id=wxID_PNLEDITPICTURECMDROTATERIGHT, name="cmdRotateRight",
               parent=self, pos=wx.Point(-1, -1), size=wx.Size(-1, -1),
               style=wx.BU_AUTODRAW)
         self.cmdRotateRight.SetBitmapDisabled(wx.ArtProvider.GetBitmap('PFS_IMAGE_ROTATION_RIGHT_D_16'))
@@ -177,11 +163,11 @@ class PnlEditPicture(wx.Panel):
               id=wxID_PNLEDITPICTURECMDROTATERIGHT)
 
         self.stEffect = wx.StaticText(id=wxID_PNLEDITPICTURESTEFFECT,
-              label=_(u'Effect:'), name=u'stEffect', parent=self,
+              label=_("Effect:"), name="stEffect", parent=self,
               pos=wx.Point(-1, -1), size=wx.Size(-1, -1), style=0)
 
         self.choiceEffect = wx.Choice(choices=[],
-              id=wxID_PNLEDITPICTURECHOICEEFFECT, name=u'choiceEffect',
+              id=wxID_PNLEDITPICTURECHOICEEFFECT, name="choiceEffect",
               parent=self, pos=wx.Point(-1, -1), size=wx.Size(-1, -1), style=0)
         self.choiceEffect.Bind(wx.EVT_CHOICE, self.OnChoiceEffectChoice,
               id=wxID_PNLEDITPICTURECHOICEEFFECT)
@@ -191,39 +177,39 @@ class PnlEditPicture(wx.Panel):
               size=wx.Size(-1, -1), style=wx.LI_VERTICAL)
 
         self.stProcess = wx.StaticText(id=wxID_PNLEDITPICTURESTPROCESS,
-              label=_(u'Process'), name=u'stProcess', parent=self,
+              label=_("Process"), name="stProcess", parent=self,
               pos=wx.Point(-1, -1), size=wx.Size(-1, -1), style=0)
 
         self.stMovement = wx.StaticText(id=wxID_PNLEDITPICTURESTMOVEMENT,
-              label=_(u'Movement:'), name=u'stMovement', parent=self,
+              label=_("Movement:"), name='stMovement', parent=self,
               pos=wx.Point(-1, -1), size=wx.Size(-1, -1), style=0)
 
         self.choiceMovement = wx.Choice(choices=[],
-              id=wxID_PNLEDITPICTURECHOICEMOVEMENT, name=u'choiceMovement',
+              id=wxID_PNLEDITPICTURECHOICEMOVEMENT, name="choiceMovement",
               parent=self, pos=wx.Point(-1, -1), size=wx.Size(-1, -1), style=0)
 
         self.pnlImgDuration = PnlFloatSpinCtrl(id=wxID_PNLEDITPICTUREPNLIMGDURATION,
-              name=u'pnlImgDuration', parent=self, pos=wx.Point(-1, -1),
+              name="pnlImgDuration", parent=self, pos=wx.Point(-1, -1),
               size=wx.Size(-1, -1), style=wx.TAB_TRAVERSAL)
 
         self.stDurationUnit = wx.StaticText(id=wxID_PNLEDITPICTURESTDURATIONUNIT,
-              label=_(u'sec'), name=u'stDurationUnit', parent=self,
+              label=_("sec"), name="stDurationUnit", parent=self,
               pos=wx.Point(-1, -1), size=wx.Size(-1, -1), style=0)
 
         self.stTrans = wx.StaticText(id=wxID_PNLEDITPICTURESTTRANS,
-              label=_(u'Transition:'), name=u'stTrans', parent=self,
+              label=_("Transition:"), name="stTrans", parent=self,
               pos=wx.Point(-1, -1), size=wx.Size(-1, -1), style=0)
 
         self.choiceTrans = wx.Choice(choices=[],
-              id=wxID_PNLEDITPICTURECHOICETRANS, name=u'choiceTrans',
+              id=wxID_PNLEDITPICTURECHOICETRANS, name="choiceTrans",
               parent=self, pos=wx.Point(-1, -1), size=wx.Size(-1, -1), style=0)
 
         self.pnlTransDuration = PnlFloatSpinCtrl(id=wxID_PNLEDITPICTUREPNLTRANSDURATION,
-              name=u'pnlTransDuration', parent=self, pos=wx.Point(-1, -1),
+              name="pnlTransDuration", parent=self, pos=wx.Point(-1, -1),
               size=wx.Size(-1, -1), style=wx.TAB_TRAVERSAL)
 
         self.stTransUnit = wx.StaticText(id=wxID_PNLEDITPICTURESTTRANSUNIT,
-              label=_(u'sec'), name=u'stTransUnit', parent=self,
+              label=_("sec"), name="stTransUnit", parent=self,
               pos=wx.Point(-1, -1), size=wx.Size(-1, -1), style=0)
 
         self.staticLine2 = wx.StaticLine(id=wxID_PNLEDITPICTURESTATICLINE2,
@@ -231,11 +217,11 @@ class PnlEditPicture(wx.Panel):
               size=wx.Size(-1, -1), style=wx.LI_VERTICAL)
 
         self.stSubtitle = wx.StaticText(id=wxID_PNLEDITPICTURESTSUBTITLE,
-              label=_(u'Subtitle'), name=u'stSubtitle', parent=self,
+              label=_("Subtitle"), name="stSubtitle", parent=self,
               pos=wx.Point(-1, -1), size=wx.Size(-1, -1), style=0)
 
         self.tcComment = wx.TextCtrl(id=wxID_PNLEDITPICTURETCCOMMENT,
-              name=u'tcComment', parent=self, pos=wx.Point(-1, -1),
+              name="tcComment", parent=self, pos=wx.Point(-1, -1),
               size=wx.Size(-1, -1), style=wx.TE_MULTILINE, value='')
         self.tcComment.Bind(wx.EVT_TEXT, self.OnTextCtrlCommentText,
               id=wxID_PNLEDITPICTURETCCOMMENT)
@@ -251,9 +237,9 @@ class PnlEditPicture(wx.Panel):
         self.stProcess.SetFont(font)
         self.stSubtitle.SetFont(font)
 
-        self.choiceMovement.Append(_(u"Linear"), Picture.MOVE_LINEAR)
-        self.choiceMovement.Append(_(u"Accelerated"), Picture.MOVE_ACCEL)
-        self.choiceMovement.Append(_(u"Delayed"), Picture.MOVE_DELAYED)
+        self.choiceMovement.Append(_("Linear"), Picture.MOVE_LINEAR)
+        self.choiceMovement.Append(_("Accelerated"), Picture.MOVE_ACCEL)
+        self.choiceMovement.Append(_("Delayed"), Picture.MOVE_DELAYED)
         self.choiceMovement.SetSelection(1)
         self.choiceMovement.Bind(wx.EVT_CHOICE, self.OnChoiceMvmntChoice)
 
@@ -261,28 +247,40 @@ class PnlEditPicture(wx.Panel):
         self.pnlImgDuration.SetValue(7)
         self.pnlImgDuration.Bind(EVT_VALUE_CHANGED, self.OnImgDurationChanged)
 
-        self.choiceEffect.Append(_(u"No effect"), Picture.EFFECT_NONE)
-        self.choiceEffect.Append(_(u"Black and White"), Picture.EFFECT_BLACK_WHITE)
-        self.choiceEffect.Append(_(u"Sepia tone"), Picture.EFFECT_SEPIA)
+        self.choiceEffect.Append(_("No effect"), Picture.EFFECT_NONE)
+        self.choiceEffect.Append(_("Black and White"), Picture.EFFECT_BLACK_WHITE)
+        self.choiceEffect.Append(_("Sepia tone"), Picture.EFFECT_SEPIA)
         self.choiceEffect.SetSelection(0)
 
         self.pnlTransDuration.SetRange(5, 200)
         self.pnlTransDuration.SetValue(1)
         self.pnlTransDuration.Bind(EVT_VALUE_CHANGED, self.OnTransDurationChanged)
-        self.choiceTrans.Append(_(u"None"), Picture.TRANS_NONE)
-        self.choiceTrans.Append(_(u"Fade"), Picture.TRANS_FADE)
-        self.choiceTrans.Append(_(u"Roll"), Picture.TRANS_ROLL)
+        self.choiceTrans.Append(_("None"), Picture.TRANS_NONE)
+        self.choiceTrans.Append(_("Fade"), Picture.TRANS_FADE)
+        self.choiceTrans.Append(_("Roll"), Picture.TRANS_ROLL)
         self.choiceTrans.SetSelection(1)
         self.choiceTrans.Bind(wx.EVT_CHOICE, self.OnChoiceTransChoice)
 
         self._pictures = []
         self.SetPictures(None)
 
-    def __SetChoiceSelectionByData(self, choice, data):
+    def __FindChoiceIdxByData(self, choice, data):
         for idx in range(choice.GetCount()):
             if choice.GetClientData(idx) == data:
-                choice.Select(idx)
-                return
+                return idx
+        return wx.NOT_FOUND
+
+    def __GetChoiceDataBySelection(self, choice):
+        selIdx = choice.GetSelection()
+        if selIdx != wx.NOT_FOUND:
+            return choice.GetClientData(selIdx)
+        else:
+            return None
+
+    def __SetChoiceSelectionByData(self, choice, data):
+        idx = self.__FindChoiceIdxByData(choice, data)
+        if idx != wx.NOT_FOUND:
+            choice.Select(idx)
 
     def OnCmdRotateLeftButton(self, event):
         for pic in self._pictures:
@@ -334,7 +332,7 @@ class PnlEditPicture(wx.Panel):
         if self._pictures:
             pic = self._pictures[0]
 
-            self.tcComment.SetValue(pic.GetComment())
+            self.tcComment.ChangeValue(pic.GetComment())
             self.pnlImgDuration.SetValue(pic.GetDuration())
             self.__SetChoiceSelectionByData(self.choiceMovement, pic.GetMovement())
             self.__SetChoiceSelectionByData(self.choiceEffect, pic.GetEffect())
@@ -342,3 +340,30 @@ class PnlEditPicture(wx.Panel):
             self.__SetChoiceSelectionByData(self.choiceTrans, pic.GetTransition())
             self.pnlTransDuration.SetValue(pic.GetTransitionDuration(rawValue=True))
             self.pnlTransDuration.Enable(pic.GetTransition() != Picture.TRANS_NONE)
+
+    def SetupModeByProject(self, project):
+        if project.GetTimelapse():
+            selTrans = self.choiceTrans.GetSelection()
+            rollIdx = self.__FindChoiceIdxByData(
+                self.choiceTrans, Picture.TRANS_ROLL)
+            if rollIdx != wx.NOT_FOUND:
+                self.choiceTrans.Delete(rollIdx)
+            if rollIdx == selTrans:
+                self.choiceTrans.Select(0)
+
+            unit = _("fpp")
+            tooltip = _("frames per picture - the number of frames each picture will be shown")
+        else:
+            projDuration = project.GetDuration(calc=False)
+            if projDuration is None:
+                unit = _('sec')
+            else:
+                # project duration is set to a fixed value (or by music), so
+                # the units are not seconds but kind of ratio time
+                unit = "-"
+            tooltip = ""
+
+        self.stDurationUnit.SetLabel(unit)
+        self.stTransUnit.SetLabel(unit)
+        self.stDurationUnit.SetToolTip(tooltip)
+        self.stTransUnit.SetToolTip(tooltip)
