@@ -1,24 +1,10 @@
 # Boa:FramePanel:PnlFloatSpinCtrl
-# encoding: UTF-8
+# -*- coding: utf-8 -*-
 #
 # PhotoFilmStrip - Creates movies out of your pictures.
 #
 # Copyright (C) 2010 Jens Goepfert
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
 
 import wx
 
@@ -48,20 +34,20 @@ class PnlFloatSpinCtrl(wx.Panel):
     def _init_ctrls(self, prnt):
         # generated method, don't edit
         wx.Panel.__init__(self, id=wxID_PNLFLOATSPINCTRL,
-              name=u'PnlFloatSpinCtrl', parent=prnt, pos=wx.Point(-1, -1),
+              name="PnlFloatSpinCtrl", parent=prnt, pos=wx.Point(-1, -1),
               size=wx.Size(-1, -1), style=wx.TAB_TRAVERSAL)
         self.SetClientSize(wx.Size(169, 31))
 
         self.tcValue = wx.TextCtrl(id=wxID_PNLFLOATSPINCTRLTCVALUE,
-              name=u'tcValue', parent=self, pos=wx.Point(-1, -1),
-              size=wx.Size(-1, -1), style=0, value=u'5.0')
+              name="tcValue", parent=self, pos=wx.Point(-1, -1),
+              size=wx.Size(-1, -1), style=0, value="5.0")
         self.tcValue.Bind(wx.EVT_KILL_FOCUS, self.OnTextCtrlValueKillFocus,
               id=wxID_PNLFLOATSPINCTRLTCVALUE)
         self.tcValue.Bind(wx.EVT_TEXT, self.OnTextCtrlValueText,
               id=wxID_PNLFLOATSPINCTRLTCVALUE)
 
         self.spinButtonValue = wx.SpinButton(id=wxID_PNLFLOATSPINCTRLSPINBUTTONVALUE,
-              name=u'spinButtonValue', parent=self, pos=wx.Point(-1, -1),
+              name="spinButtonValue", parent=self, pos=wx.Point(-1, -1),
               size=wx.Size(-1, -1), style=wx.SP_VERTICAL)
         self.spinButtonValue.Bind(wx.EVT_SPIN, self.OnSpinButtonValueSpin,
               id=wxID_PNLFLOATSPINCTRLSPINBUTTONVALUE)
