@@ -1,23 +1,7 @@
 # Boa:FramePanel:PnlJobManager
-# encoding: UTF-8
+# -*- coding: utf-8 -*-
 #
-# PhotoFilmStrip - Creates movies out of your pictures.
-#
-# Copyright (C) 2012 Jens Goepfert
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Copyright (C) 2018 Jens Goepfert
 #
 
 import wx
@@ -53,17 +37,17 @@ class PnlJobManager(wx.Panel, WxVisualJobManager):
 
     def _init_ctrls(self, prnt):
         # generated method, don't edit
-        wx.Panel.__init__(self, id=wxID_PNLJOBMANAGER, name=u'PnlJobManager',
+        wx.Panel.__init__(self, id=wxID_PNLJOBMANAGER, name="PnlJobManager",
               parent=prnt, pos=wx.Point(-1, -1), size=wx.Size(-1, -1),
               style=wx.TAB_TRAVERSAL)
         self.SetClientSize(wx.Size(400, 250))
 
         self.pnlJobs = wx.lib.scrolledpanel.ScrolledPanel(id=wxID_PNLJOBMANAGERPNLJOBS,
-              name=u'pnlJobs', parent=self, pos=wx.Point(-1, -1),
+              name="pnlJobs", parent=self, pos=wx.Point(-1, -1),
               size=wx.Size(-1, -1), style=wx.SUNKEN_BORDER)
 
         self.cmdClear = wx.Button(id=wxID_PNLJOBMANAGERCMDCLEAR,
-              label=_(u'&Clear list'), name=u'cmdClear', parent=self,
+              label=_("&Clear list"), name="cmdClear", parent=self,
               pos=wx.Point(-1, -1), size=wx.Size(-1, -1), style=0)
         self.cmdClear.Bind(wx.EVT_BUTTON, self.OnCmdClearButton,
               id=wxID_PNLJOBMANAGERCMDCLEAR)
